@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Plack::App::Directory::Template;
 {
-  $Plack::App::Directory::Template::VERSION = '0.25';
+  $Plack::App::Directory::Template::VERSION = '0.26';
 }
 #ABSTRACT: Serve static files from document root with directory index template
 
@@ -85,7 +85,8 @@ sub serve_path {
         $env->{'tt.vars'} = $tt_vars;
     }
 
-    $env->{'tt.template'} = ref $self->templates ? $self->templates : 'index.html';
+    $env->{'tt.template'} = ref $self->templates ? $self->templates 
+                          : ($self->{PROCESS} // 'index.html');
 
     $self->{tt} //= Plack::Middleware::TemplateToolkit->new(
         INCLUDE_PATH => $self->templates
@@ -106,7 +107,7 @@ sub template_vars {
 
 package Plack::App::Directory::Template::File;
 {
-  $Plack::App::Directory::Template::File::VERSION = '0.25';
+  $Plack::App::Directory::Template::File::VERSION = '0.26';
 }
 
 our $AUTOLOAD;
@@ -169,7 +170,7 @@ Plack::App::Directory::Template - Serve static files from document root with dir
 
 =head1 VERSION
 
-version 0.25
+version 0.26
 
 =head1 SYNOPSIS
 
@@ -213,14 +214,16 @@ modify and extend file objects.
 
 =item L<Template> configuration
 
-Template Toolkit configuration options (e.g. C<PRE_PROCESS>, C<POST_CHOMP> etc.)
-are supported as well.
+Template Toolkit configuration options (C<PRE_PROCESS>, C<POST_CHOMP>,
+C<PROCESS> etc.) are supported as well.
 
 =back
 
 =head1 TEMPLATE VARIABLES
 
-The following variables are passed to the directory index template:
+The following variables are passed to the directory index template. Have a look
+at the default template, shipped as file C<share/index.html> with this module,
+for usage example.
 
 =over 4
 
